#!/usr/bin/env Rscript

library(dplyr, warn.conflicts = FALSE)
library(readr, warn.conflicts = FALSE)

config <- yaml::read_yaml('config.yml')

col_types  <- cols(
    .default = col_double(),
    FID      = col_character(),
    IID      = col_character()
)

# read and combine individual expression data in long format
config$brain_regions %>%
    purrr::map(
        function(x) {
            sprintf("%s/gene_expression/%s.expression.txt", config$output_dir, x) %>%
                read_tsv(col_types = col_types, progress = FALSE) %>%
                tidyr::gather('ensembl_gene_id', 'expression', -FID, -IID) %>%
                mutate(tissue = x) %>%
                select(tissue, everything())
        }
    ) %>%
    {do.call(rbind, .)} %>%
    # make missing genes explicit
    tidyr::spread(ensembl_gene_id, expression, fill = NA_real_) %>%
    tidyr::gather('ensembl_gene_id', 'expression', -FID, -IID, -tissue) %>%
    write_rds(sprintf('%s/gene_expressions_combined.rds', config$output_dir), compress = 'gz')
